@@ -1,7 +1,6 @@
 package Net::Google::DataAPI::Role::HasContent;
 use Any::Moose '::Role';
-use namespace::autoclean;
-our $VERSION='0.02';
+our $VERSION='0.03';
 
 requires 'update';
 
@@ -29,6 +28,8 @@ sub param {
     }
 }
 
+no Any::Moose '::Role';
+
 1;
 
 __END__
