@@ -5,7 +5,7 @@ use Net::Google::DataAPI::Auth::AuthSub;
 use Net::Google::AuthSub;
 use URI;
 
-our $VERSSION = '0.02';
+our $VERSION = '0.02';
 
 role_type 'Net::Google::DataAPI::Types::Auth'
     => {role => 'Net::Google::DataAPI::Role::Auth'};
